summaryrefslogtreecommitdiff
path: root/types.h
diff options
context:
space:
mode:
authorLeo Tenenbaum <pommicket@gmail.com>2020-02-24 10:41:42 -0500
committerLeo Tenenbaum <pommicket@gmail.com>2020-02-24 10:41:42 -0500
commitb206d88474670956035ff25d5b392fb2925b015d (patch)
tree93d195bb03aa42c2f3e8045fed46d2dd64bde08f /types.h
parent6f5a2bb7b7017bb574a32ff1c06449a1f9843214 (diff)
oops turns out we werent generating redeclaration errors
Diffstat (limited to 'types.h')
-rw-r--r--types.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/types.h b/types.h
index a6e49dc..04b6dea 100644
--- a/types.h
+++ b/types.h
@@ -170,7 +170,7 @@ typedef union Value {
typedef enum {
IDECL_NONE,
IDECL_DECL,
- IDECL_FOR
+ IDECL_EXPR
} IdentDeclKind;
@@ -181,7 +181,7 @@ typedef struct IdentSlot {
IdentDeclKind decl_kind;
union {
struct Declaration *decl;
- struct ForExpr *for_;
+ struct Expression *decl_expr;
};
struct Identifiers *idents;
SOURCE_LOCATION
@@ -899,7 +899,7 @@ typedef struct Typer {
Allocator *allocr;
Evaluator *evalr;
Identifiers *globals;
- ForExpr **in_fors; /* which fors we are currently inside the header of */
+ Expression **in_exprs; /* which expression declarations we are currently inside (e.g. for x := foo)*/
Declaration **in_decls; /* array of declarations we are currently inside */
Block *block;
Block **blocks; /* dyn array of all the block's we're in ([0] = NULL for global scope) */